==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/Visual/projectm/translations/projectm_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="41"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="150"/>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="150"/>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="151"/>
        <source>&amp;Show Song Title</source>
        <translation>&amp;Weergeef Titel van Nummer</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="151"/>
        <source>F2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="152"/>
        <source>&amp;Show Preset Name</source>
        <translation>&amp;Weergeef Naam van Voorinstellingen</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="152"/>
        <source>F3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="153"/>
        <source>&amp;Show Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="153"/>
        <source>M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="155"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Volgende Instelling</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="155"/>
        <source>N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="156"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Vorige Instelling</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="156"/>
        <source>P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="157"/>
        <source>&amp;Random Preset</source>
        <translation>&amp;Willekeurige Instelling</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="157"/>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="158"/>
        <source>&amp;Lock Preset</source>
        <translation>&amp;Zet Instelling Vast</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="158"/>
        <source>L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="160"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Volledig scherm</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="160"/>
        <source>F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="29"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="49"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Over de ProjectM Visuele Module</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>ProjectM Visuele Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Deze plugin voegt projectM visualisatie toe</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Based on libprojectM-qt library</source>
        <translation>Gebasseerd op de libprojectM-qt bibliotheek</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/Visual/projectm/translations/projectm_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>ProjectMPlugin</name>
    <message>
        <location filename="../projectmplugin.cpp" line="41"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
</context>
<context>
    <name>ProjectMWidget</name>
    <message>
        <location filename="../projectmwidget.cpp" line="150"/>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="150"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="151"/>
        <source>&amp;Show Song Title</source>
        <translation>&amp;Weergeef Titel van Nummer</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="151"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="152"/>
        <source>&amp;Show Preset Name</source>
        <translation>&amp;Weergeef Naam van Voorinstellingen</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="152"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="153"/>
        <source>&amp;Show Menu</source>
        <translation>Menu &amp;tonen</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="153"/>
        <source>M</source>
        <translation>M</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="155"/>
        <source>&amp;Next Preset</source>
        <translation>&amp;Volgende Instelling</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="155"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="156"/>
        <source>&amp;Previous Preset</source>
        <translation>&amp;Vorige Instelling</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="156"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="157"/>
        <source>&amp;Random Preset</source>
        <translation>&amp;Willekeurige Instelling</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="157"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="158"/>
        <source>&amp;Lock Preset</source>
        <translation>&amp;Zet Instelling Vast</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="158"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="160"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Volledig scherm</translation>
    </message>
    <message>
        <location filename="../projectmwidget.cpp" line="160"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>VisualProjectMFactory</name>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="29"/>
        <source>ProjectM</source>
        <translation>ProjectM</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="49"/>
        <source>About ProjectM Visual Plugin</source>
        <translation>Over de ProjectM Visuele Module</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="50"/>
        <source>Qmmp ProjectM Visual Plugin</source>
        <translation>ProjectM Visuele Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="51"/>
        <source>This plugin adds projectM visualization</source>
        <translation>Deze plugin voegt projectM visualisatie toe</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../visualprojectmfactory.cpp" line="53"/>
        <source>Based on libprojectM-qt library</source>
        <translation>Gebasseerd op de libprojectM-qt bibliotheek</translation>
    </message>
</context>
</TS>
